@@ -59,7 +59,7 @@ class _OPCLIExecute:
         try:
             output, _, _ = cls._run_raw(
                 argv, input_string=input_string, capture_stdout=capture_stdout, env=env)
-            if decode:
+            if decode and output is not None:
                 output = output.decode(decode)
         except FileNotFoundError as err:
             cls.logger.error(
@@ -76,5 +76,5 @@ class _OPCLIExecute:
         print("logger has been set")
 
     @classmethod
-    def set_log_level(cls, log_level: int):
+    def set_log_level(cls, log_level: int):  # pragma: no coverage
         cls.logger.setLevel(log_level)
