@@ -4,6 +4,9 @@ from .json import safe_unjson
 
 
 class OPAccount(dict):
+    def __init__(self, account_dict_or_json):
+        account_dict = safe_unjson(account_dict_or_json)
+        super().__init__(account_dict)
 
     @property
     def url(self) -> str:
@@ -35,10 +38,17 @@ class OPAccountList(List[OPAccount]):
             op_account = OPAccount(account_dict)
             self.append(op_account)
 
-    def account_for_email(self, email: str):
+    def account_for_identifier(self, account_id: str):
         acct = None
         for account in self:
-            if account.email == email:
+            if account_id in [account.account_uuid, account.user_uuid, account.shorthand, account.email, account.url]:
                 acct = account
                 break
         return acct
+
+    def user_id_for_account_identifier(self, account_id: str):
+        user_id = None
+        acct = self.account_for_identifier(account_id)
+        if acct:
+            user_id = acct.user_uuid
+        return user_id
