@@ -1,27 +1,42 @@
+from typing import Union
+
+from ._item_descriptor_base import OPAbstractItemDescriptor
+from ._item_descriptor_registry import op_register_item_descriptor_type
 from ._op_item_type_registry import op_register_item_type
-from ._op_items_base import OPAbstractItem
+from ._op_items_base import OPAbstractItem, OPFieldNotFoundException
+
+
+@op_register_item_descriptor_type
+class OPServerItemDescriptor(OPAbstractItemDescriptor):
+    CATEGORY = "SERVER"
+
+    def __init__(self, item_dict):
+        super().__init__(item_dict)
 
 
 @op_register_item_type
 class OPServerItem(OPAbstractItem):
-    TEMPLATE_ID = "110"
+    CATEGORY = "SERVER"
 
     def __init__(self, item_dict):
         super().__init__(item_dict)
 
     @property
     def password(self):
-        password = self.primary_section_field_value("password")
+        password = self.field_value_by_id("password")
         return password
 
     @property
     def username(self):
-        username = self.primary_section_field_value("username")
+        username = self.field_value_by_id("username")
         return username
 
     @property
-    def url(self):
-        url = self.primary_section_field_value("URL")
+    def url(self) -> Union[str, None]:
+        try:
+            url = self.field_value_by_id("url")
+        except OPFieldNotFoundException:
+            url = None
         return url
 
     @property
@@ -32,7 +47,8 @@ class OPServerItem(OPAbstractItem):
 
     @property
     def admin_console_username(self):
-        username = self.field_value_by_section_title("admin console username")
+        username = self.field_value_by_section_title(
+            "Admin Console", "admin console username")
         return username
 
     @property
